@@ -14,11 +14,7 @@
 #include <arpa/inet.h>
 #include <ctype.h>
 #include <grp.h>
-
-#ifdef HAVE_NETDB_H
 #include <netdb.h>
-#endif /* HAVE_NETDB_H */
-
 #include <netinet/in.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,7 +29,6 @@
 #include <atalk/fce_api.h>
 #include <atalk/globals.h>
 #include <atalk/logger.h>
-#include <atalk/paths.h>
 #include <atalk/util.h>
 
 #include "status.h"
@@ -65,7 +60,15 @@ static void show_version( void )
 		printf( "%d.%d ", afp_versions[ i ].av_number/10, afp_versions[ i ].av_number%10);
 	}
 	puts( "" );
+	printf("        TCP/IP Support:\t");
+	puts("Yes");
 
+	printf("     AppleTalk Support:\t");
+#ifdef NO_DDP
+	puts("No");
+#else
+	puts("Yes");
+#endif
 	printf( "         CNID backends:\t" );
 #ifdef CNID_BACKEND_DBD
 	printf( "dbd " );
