@@ -80,7 +80,6 @@
 #include <atalk/util.h>
 #include <atalk/logger.h>
 #include <atalk/cnid_bdb_private.h>
-#include <atalk/paths.h>
 #include <atalk/compat.h>
 #include <atalk/errchk.h>
 #include <atalk/bstrlib.h>
@@ -259,8 +258,8 @@ static struct server *test_usockfn(const char *path)
             }
         }
 
-        sprintf(buf1, "%i", sv[1]);
-        sprintf(buf2, "%i", rqstfd);
+        snprintf(buf1, sizeof(buf1), "%i", sv[1]);
+        snprintf(buf2, sizeof(buf2), "%i", rqstfd);
 
         if (up->count == MAXSPAWN) {
             /* there's a pb with the db inform child, it will delete the db */
@@ -303,7 +302,7 @@ static int set_dbdir(const char *dbdir, const char *vpath)
 {
     EC_INIT;
     struct stat st;
-    bstring oldpath, newpath;
+    bstring oldpath, newpath = NULL;
     char *cmd_argv[4];
 
     LOG(log_debug, logtype_cnid, "set_dbdir: volume: %s, db path: %s", vpath, dbdir);
@@ -422,10 +421,10 @@ static int setlimits(void)
         LOG(log_error, logtype_afpd, "setlimits: %s", strerror(errno));
         exit(1);
     }
-    if (rlim.rlim_cur != RLIM_INFINITY && rlim.rlim_cur < 65535) {
-        rlim.rlim_cur = 65535;
-        if (rlim.rlim_max != RLIM_INFINITY && rlim.rlim_max < 65535)
-            rlim.rlim_max = 65535;
+    if (rlim.rlim_cur != RLIM_INFINITY && rlim.rlim_cur < RLIM_MAX) {
+        rlim.rlim_cur = RLIM_MAX;
+        if (rlim.rlim_max != RLIM_INFINITY && rlim.rlim_max < RLIM_MAX)
+            rlim.rlim_max = RLIM_MAX;
         if (setrlimit(RLIMIT_NOFILE, &rlim) != 0) {
             LOG(log_error, logtype_afpd, "setlimits: %s", strerror(errno));
             exit(1);
@@ -472,27 +471,49 @@ int main(int argc, char *argv[])
             debug = 1;
             break;
         case 'F':
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             obj.cmdlineconfigfile = strdup(optarg);
             break;
         case 'v':
         case 'V':
             printf("cnid_metad (Netatalk %s)\n", VERSION);
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             return -1;
         default:
             printf("cnid_metad [-dvV] [-F alternate configfile ]\n");
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             return -1;
         }
     }
 
-    if (!debug && daemonize(0, 0) != 0)
+    if (!debug && daemonize() != 0) {
+        if (obj.cmdlineconfigfile != NULL) {
+            free((void *)obj.cmdlineconfigfile);
+        }
         exit(EXITERR_SYS);
+    }
 
-    if (afp_config_parse(&obj, "cnid_metad") != 0)
+    if (afp_config_parse(&obj, "cnid_metad") != 0) {
+        if (obj.cmdlineconfigfile != NULL) {
+            free((void *)obj.cmdlineconfigfile);
+        }
         daemon_exit(1);
+    }
+
+    if (obj.cmdlineconfigfile != NULL) {
+        free((void *)obj.cmdlineconfigfile);
+        obj.cmdlineconfigfile = NULL;
+    }
 
     (void)setlimits();
 
-    host = atalk_iniparser_getstrdup(obj.iniconfig, INISEC_GLOBAL, "cnid listen", "localhost:4700");
+    host = INIPARSER_GETSTRDUP(obj.iniconfig, INISEC_GLOBAL, "cnid listen", "localhost:4700");
     if ((port = strrchr(host, ':')))
         *port++ = 0;
     else
@@ -502,6 +523,10 @@ int main(int argc, char *argv[])
 
     LOG(log_note, logtype_afpd, "CNID Server listening on %s:%s", host, port);
 
+    if (host) {
+        free(host);
+    }
+
     /* switch uid/gid */
     if (uid || gid) {
         LOG(log_debug, logtype_cnid, "Setting uid/gid to %i/%i", uid, gid);
